CA16-Cl03
open | /cms/logout |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Photos |
clickAndWait | link=Añadir foto |
type | id_name | CA16-Cl03 photo
select | id_status | label=Publicado
type | id_image | C:\Documents and Settings\mrivera\Escritorio\Merengue\test-data\test_pdf.pdf
clickAndWait | _save |
verifyTextPresent | Por favor, corrija el siguiente error. |
verifyTextPresent | Envíe una imagen válida. El fichero que ha enviado no era una imagen o se trataba de una imagen corrupta. |
clickAndWait | link=Terminar sesión |